@@ -49,13 +49,40 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CreateAsrKeyWordLib(self, request):
+        """用户通过本接口进行关键字词表的创建。
+        <br>•   默认每个用户最多可创建30个关键字词表。
+        <br>•   每个关键词词表最多可添加100个词，每个词最多5个汉字或15个字符。
+        <br>•   词表通过本地文件形式上传。
+        <br>•   本地文件必须为UTF-8编码格式，每行仅添加一个词且不能包含标点和特殊字符。
+
+        :param request: Request instance for CreateAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.CreateAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.CreateAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CreateAsrVocab(self, request):
         """用户通过本接口进行热词表的创建。
         <br>•   默认最多可创建30个热词表。
         <br>•   每个热词表最多可添加1000个词，每个词最长10个汉字或30个英文字符，不能超出限制。
         <br>•   热词表可以通过数组或者本地文件形式上传。
         <br>•   本地文件必须为UTF-8编码格式，每行仅添加一个热词且不能包含标点和特殊字符。
-        <br>•   热词权重取值范围为[1,11]之间的整数，权重越大代表该词被识别出来的概率越大。
+        <br>•   热词权重取值范围为[1,11]之间的整数或者100，权重越大代表该词被识别出来的概率越大。
         <br>• 注意:  热词权重设置为11时，当前热词将升级为超级热词，建议仅将重要且必须生效的热词设置到11，设置过多权重为11的热词将影响整体字准率。
 
         :param request: Request instance for CreateAsrVocab.
@@ -140,7 +167,7 @@ class AsrClient(AbstractClient):
         • 音频提交方式：本接口支持**音频 URL 、本地音频文件**两种请求方式。推荐使用 [腾讯云COS](https://cloud.tencent.com/document/product/436/38484) 来存储、生成URL并提交任务，此种方式将不产生外网和流量下行费用，可节约成本、提升任务速度（COS桶权限需要设置公有读私有写，或URL设置外部可访问）
         • 音频限制：音频 URL 时长不能大于5小时，文件大小不超过1GB；本地音频文件不能大于5MB
         • 如何获取识别结果：支持**回调或轮询**的方式获取结果，具体请参考 [录音文件识别结果查询](https://cloud.tencent.com/document/product/1093/37822)
-        • 识别结果有效时间：在服务端保存7天
+        • 识别结果有效时间：识别结果在服务端保存24小时
         • 签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法 v3
 
         :param request: Request instance for CreateRecTask.
@@ -163,6 +190,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DeleteAsrKeyWordLib(self, request):
+        """用户通过本接口进行关键词表的删除。
+
+        :param request: Request instance for DeleteAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.DeleteAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.DeleteAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DeleteAsrVocab(self, request):
         """用户通过本接口进行热词表的删除。
 
@@ -234,12 +284,13 @@ class AsrClient(AbstractClient):
 
 
     def DescribeTaskStatus(self, request):
-        """在调用录音文件识别请求接口后，有回调和轮询两种方式获取识别结果。
-        <br>• 当采用回调方式时，识别完成后会将结果通过 POST 请求的形式通知到用户在请求时填写的回调 URL，具体请参见[ 录音识别结果回调 ](https://cloud.tencent.com/document/product/1093/52632)。
-        <br>• 当采用轮询方式时，需要主动提交任务ID来轮询识别结果，共有任务成功、等待、执行中和失败四种结果，具体信息请参见下文说明。
-        <br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
-        <br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
-        <br>•   默认接口请求频率限制：50次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
+        """调用录音文件识别请求接口后，有回调和轮询两种方式获取识别结果。
+        • **注意任务有效期为24小时，超过24小时的任务请不要再查询，且不要依赖TaskId作为业务唯一ID，不同日期可能出现重复TaskId。**
+        • 当采用回调方式时，识别完成后会将结果通过 POST 请求的形式通知到用户在请求时填写的回调 URL，具体请参见[ 录音识别结果回调 ](https://cloud.tencent.com/document/product/1093/52632)。
+        • 当采用轮询方式时，需要主动提交任务ID来轮询识别结果，共有任务成功、等待、执行中和失败四种结果，具体信息请参见下文说明。
+        •   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
+        •   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        •   默认接口请求频率限制：50次/秒，如您有提高请求频率限制的需求，请提[工单](https://console.cloud.tencent.com/workorder/category)进行咨询。
 
         :param request: Request instance for DescribeTaskStatus.
         :type request: :class:`tencentcloud.asr.v20190614.models.DescribeTaskStatusRequest`
@@ -307,6 +358,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetAsrKeyWordLibList(self, request):
+        """用户通过该接口，可获得所有的关键词表及其信息。
+
+        :param request: Request instance for GetAsrKeyWordLibList.
+        :type request: :class:`tencentcloud.asr.v20190614.models.GetAsrKeyWordLibListRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.GetAsrKeyWordLibListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetAsrKeyWordLibList", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetAsrKeyWordLibListResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def GetAsrVocab(self, request):
         """用户根据词表的ID可以获取对应的热词表信息
 
@@ -399,6 +473,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def GetUsageByDate(self, request):
+        """查询用户用量
+
+        :param request: Request instance for GetUsageByDate.
+        :type request: :class:`tencentcloud.asr.v20190614.models.GetUsageByDateRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.GetUsageByDateResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("GetUsageByDate", params, headers=headers)
+            response = json.loads(body)
+            model = models.GetUsageByDateResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def ModifyCustomization(self, request):
         """用户通过该接口可以更新自学习模型，如模型名称、模型类型、模型语料。
 
@@ -446,7 +543,13 @@ class AsrClient(AbstractClient):
 
 
     def SentenceRecognition(self, request):
-        """本接口用于对60秒之内的短音频文件进行识别。<br>•   支持中文普通话、英语、粤语、日语、越南语、马来语、印度尼西亚语、菲律宾语、泰语、葡萄牙语、土耳其语、阿拉伯语、印地语、法语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。<br>•   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s，音频文件大小不能超过3MB。<br>•   音频格式支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac。<br>•   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"<br>•   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。<br>•   默认接口请求频率限制：30次/秒，如您有提高请求频率限制的需求，请[前往购买](https://buy.cloud.tencent.com/asr)。
+        """本接口用于对60秒之内的短音频文件进行识别。
+        •   支持中文普通话、英语、粤语、日语、越南语、马来语、印度尼西亚语、菲律宾语、泰语、葡萄牙语、土耳其语、阿拉伯语、印地语、法语、德语、上海话、四川话、武汉话、贵阳话、昆明话、西安话、郑州话、太原话、兰州话、银川话、西宁话、南京话、合肥话、南昌话、长沙话、苏州话、杭州话、济南话、天津话、石家庄话、黑龙江话、吉林话、辽宁话。
+        •   支持本地语音文件上传和语音URL上传两种请求方式，音频时长不能超过60s，音频文件大小不能超过3MB。推荐使用 [腾讯云COS](https://cloud.tencent.com/document/product/436/38484) 来存储音频、生成URL并提交请求，此种方式会走内网下载音频，极大降低整体请求时延；并且不会产生外网和流量下行费用，可节约成本（COS桶权限需要设置公有读私有写，或URL设置时效访问签名）
+        •   音频格式支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac、 amr。
+        •   请求方法为 HTTP POST , Content-Type为"application/json; charset=utf-8"
+        •   签名方法参考 [公共参数](https://cloud.tencent.com/document/api/1093/35640) 中签名方法v3。
+        •   默认接口请求频率限制：30次/秒，如您有提高请求频率限制的需求，请[前往购买](https://buy.cloud.tencent.com/asr)。
 
         :param request: Request instance for SentenceRecognition.
         :type request: :class:`tencentcloud.asr.v20190614.models.SentenceRecognitionRequest`
@@ -491,6 +594,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def UpdateAsrKeyWordLib(self, request):
+        """用户通过本接口进行对应的关键词表信息更新。
+
+        :param request: Request instance for UpdateAsrKeyWordLib.
+        :type request: :class:`tencentcloud.asr.v20190614.models.UpdateAsrKeyWordLibRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.UpdateAsrKeyWordLibResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateAsrKeyWordLib", params, headers=headers)
+            response = json.loads(body)
+            model = models.UpdateAsrKeyWordLibResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def UpdateAsrVocab(self, request):
         """用户通过本接口进行对应的词表信息更新。
 
@@ -514,6 +640,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def VoicePrintCompare(self, request):
+        """通过比对两段音频内说话人的声纹，得到一个打分，可通过打分判断两段音频声纹相似度,  打分区间[0 - 100]。 音频要求：16k采样率， 16bit位深，pcm或者wav格式， 单声道，总时长不超过30秒的音频，base64编码数据大小不超过2M，音频内容只有一个说话人声音，并且尽可能清晰，这样结果更加准确。
+
+        :param request: Request instance for VoicePrintCompare.
+        :type request: :class:`tencentcloud.asr.v20190614.models.VoicePrintCompareRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.VoicePrintCompareResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("VoicePrintCompare", params, headers=headers)
+            response = json.loads(body)
+            model = models.VoicePrintCompareResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def VoicePrintCount(self, request):
         """统计并返回注册的说话人id总数
 
@@ -589,6 +738,29 @@ class AsrClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def VoicePrintGroupVerify(self, request):
+        """说话人验证1:N接口，可以通过传入一段说话人音频，并且指定已存在的groupId, 和返回topN,  接口返回groupId内所有声纹和传入音频声纹比对打分TopN的结果。
+
+        :param request: Request instance for VoicePrintGroupVerify.
+        :type request: :class:`tencentcloud.asr.v20190614.models.VoicePrintGroupVerifyRequest`
+        :rtype: :class:`tencentcloud.asr.v20190614.models.VoicePrintGroupVerifyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("VoicePrintGroupVerify", params, headers=headers)
+            response = json.loads(body)
+            model = models.VoicePrintGroupVerifyResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def VoicePrintUpdate(self, request):
         """本接口用于更新和覆盖已注册的音频数据和说话人昵称，更新后原有的音频数据将失效。
 
